summaryrefslogtreecommitdiff
path: root/sw/inc/cellfml.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/inc/cellfml.hxx')
-rw-r--r--sw/inc/cellfml.hxx24
1 files changed, 12 insertions, 12 deletions
diff --git a/sw/inc/cellfml.hxx b/sw/inc/cellfml.hxx
index df24004a64fb..169058938f56 100644
--- a/sw/inc/cellfml.hxx
+++ b/sw/inc/cellfml.hxx
@@ -43,7 +43,7 @@ class String;
class SwTblCalcPara
{
const SwTableBox* pLastTblBox;
- USHORT nStackCnt, nMaxSize;
+ sal_uInt16 nStackCnt, nMaxSize;
public:
SwTableSortBoxes *pBoxStk; // Stack fuers erkennen von Rekursionen !
@@ -53,9 +53,9 @@ public:
SwTblCalcPara( SwCalc& rCalculator, const SwTable& rTable );
~SwTblCalcPara();
- BOOL CalcWithStackOverflow();
- BOOL IsStackOverFlow() const { return nMaxSize == nStackCnt; }
- BOOL IncStackCnt() { return nMaxSize == ++nStackCnt; }
+ sal_Bool CalcWithStackOverflow();
+ sal_Bool IsStackOverFlow() const { return nMaxSize == nStackCnt; }
+ sal_Bool IncStackCnt() { return nMaxSize == ++nStackCnt; }
void DecStackCnt() { if( nStackCnt ) --nStackCnt; }
void SetLastTblBox( const SwTableBox* pBox ) { pLastTblBox = pBox; }
};
@@ -98,7 +98,7 @@ protected:
String sFormel; // akt. Formel
NameType eNmType; // akt. Darstellungs Art
- BOOL bValidValue; // TRUE: Formel neu berechnen
+ sal_Bool bValidValue; // sal_True: Formel neu berechnen
// suche den Node, in dem die Formel steht:
// TextFeld -> TextNode,
@@ -114,7 +114,7 @@ protected:
*rCalcPara.pTbl, &rCalcPara );
}
- static USHORT GetLnPosInTbl( const SwTable& rTbl, const SwTableBox* pBox );
+ static sal_uInt16 GetLnPosInTbl( const SwTable& rTbl, const SwTableBox* pBox );
public:
@@ -138,25 +138,25 @@ public:
void ToSplitMergeBoxNm( SwTableFmlUpdate& rTblUpd );
// ist gerade eine intern Darstellung aktiv
- BOOL IsIntrnlName() const { return eNmType == INTRNL_NAME; }
+ sal_Bool IsIntrnlName() const { return eNmType == INTRNL_NAME; }
// erfrage die akt. Darstellung der Formel
NameType GetNameType() const { return eNmType; }
// erfrage/setze das Flag, ob der akt. Wert gueltig ist
- BOOL IsValid() const { return bValidValue; }
- inline void ChgValid( BOOL bNew ) { bValidValue = bNew; }
+ sal_Bool IsValid() const { return bValidValue; }
+ inline void ChgValid( sal_Bool bNew ) { bValidValue = bNew; }
const String& GetFormula() const { return sFormel; }
void SetFormula( const String& rNew )
{
sFormel = rNew;
- bValidValue = FALSE;
+ bValidValue = sal_False;
eNmType = EXTRNL_NAME;
}
- USHORT GetBoxesOfFormula( const SwTable& rTbl, SwSelBoxes& rBoxes );
+ sal_uInt16 GetBoxesOfFormula( const SwTable& rTbl, SwSelBoxes& rBoxes );
// sind alle Boxen gueltig, auf die sich die Formel bezieht?
- BOOL HasValidBoxes() const;
+ sal_Bool HasValidBoxes() const;
};